wipe;
set T 100; 


# --------------------------------------------------------------------------------------------------------------
# U N I T S
# --------------------------------------------------------------------------------------------------------------

# Length : m
# Force  : kN
# Moment : kNm
# Stress : kPa
# Mass   : ton


# --------------------------------------------------------------------------------------------------------------
#
# M O D E L  D O M A I N  1  (6DOF)
#
# --------------------------------------------------------------------------------------------------------------

model BasicBuilder -ndm 3 -ndf 6

# --------------------------------------------------------------------------------------------------------------
# N O D E S
# --------------------------------------------------------------------------------------------------------------

# node $NodeTag $XCoord $Ycoord $Zcoord

node      1            0         0   3800        
node      2            0         0   3420        
node      3            0         0   3040        
node      4            0         0   2660        
node      5            0         0   2280        
node      6            0         0   1900        
node      7            0         0   1520        
node      8            0         0   1140        
node      9            0         0   760        
node     10            0         0   380        
node     11            0         0   0        

# --------------------------------------------------------------------------------------------------------------
# R E S T R A I N T S
# --------------------------------------------------------------------------------------------------------------

# fix $NodeTag x-transl y-transl z-transl x-rot y-rot z-rot

fix     11   1   1   1   1   1   1

# --------------------------------------------------------------------------------------------------------------
# D I S P L A C E M E N T - B A S E D   B E A M - C O L U M N   E L E M E N T S
# --------------------------------------------------------------------------------------------------------------

# Geometric Transformation

geomTransf Linear 1 0 1 0


# Sections Definition used by dispBeamColumn Elements
# (if they have not already been defined on this model domain)

set MatTag 1

uniaxialMaterial Steel02Thermal $MatTag 500000 2e+05 0.15 20 0.925 0.15 0 1 0 1 0

section fiberSecThermal 182 -GJ        10000 {


 set x1 0
 set y1 0
 set x2 20
 set y2 20 
 set n 10
 patch rect 1 $n $n $x1 $y1 $x2 $y2
 puts "a square section has been loaded";
}

# Displacement-Based Beam Column Element Definition

# element dispBeamColumn $eleTag $iNode $jNode $numIntgrPts $secTag $transfTag <-mass $massDens>

element dispBeamColumnThermal      1     11     10  3    182  1   -mass        0
element dispBeamColumnThermal      2     10      9  3    182  1   -mass        0
element dispBeamColumnThermal      3      9      8  3    182  1   -mass        0
element dispBeamColumnThermal      4      8      7  3    182  1   -mass        0
element dispBeamColumnThermal      5      7      6  3    182  1   -mass        0
element dispBeamColumnThermal      6      6      5  3    182  1   -mass        0
element dispBeamColumnThermal      7      5      4  3    182  1   -mass        0
element dispBeamColumnThermal      8      4      3  3    182  1   -mass        0
element dispBeamColumnThermal      9      3      2  3    182  1   -mass        0
element dispBeamColumnThermal     10      2      1  3    182  1   -mass        0

# --------------------------------------------------------------------------------------------------------------
#
# D O M A I N  C O M M O N S
#
# --------------------------------------------------------------------------------------------------------------

# --------------------------------------------------------------------------------------------------------------
# R E C O R D E R S
# --------------------------------------------------------------------------------------------------------------


recorder Node -file node10.out -time -node 1 -dof 3 disp
logFile "cantilever.log"



puts "Running analysis \n"

# Loads - Plain Pattern

pattern Plain 200 Linear {
 eleLoad -range 1 10 -type	-beamThermal $T  [expr $y1] $T [expr $y2];
}

# recording the initial status

record

# Analysis options

system UmfPack
numberer Plain
constraints Plain
integrator LoadControl 0.1
test NormDispIncr 1 100 1
algorithm Newton
analysis Static
set ok [analyze 10]
